@@ -1,4 +1,5 @@
 import pytest
+from pip._internal.utils.urls import path_to_url
 
 from piptools.exceptions import NoCandidateFound
 from piptools.resolver import RequirementSummary, combine_install_requirements
@@ -299,6 +300,47 @@ def test_combine_install_requirements(repository, from_line):
     assert str(combined_all.req.specifier) == "<3.2,==3.1.1,>3.0"
 
 
+def _test_combine_install_requirements_extras(repository, with_extra, without_extra):
+    combined = combine_install_requirements(repository, [without_extra, with_extra])
+    assert str(combined) == str(with_extra)
+    assert combined.extras == with_extra.extras
+
+    combined = combine_install_requirements(repository, [with_extra, without_extra])
+    assert str(combined) == str(with_extra)
+    assert combined.extras == with_extra.extras
+
+
+def test_combine_install_requirements_extras_req(repository, from_line, make_package):
+    """
+    Extras should be unioned in combined install requirements
+    (whether or not InstallRequirement.req is None, and testing either order of the inputs)
+    """
+    with_extra = from_line("edx-opaque-keys[django]==1.0.1")
+    assert with_extra.req is not None
+    without_extra = from_line("edx-opaque-keys")
+    assert without_extra.req is not None
+
+    _test_combine_install_requirements_extras(repository, with_extra, without_extra)
+
+
+def test_combine_install_requirements_extras_no_req(
+    repository, from_line, make_package
+):
+    """
+    Extras should be unioned in combined install requirements
+    (whether or not InstallRequirement.req is None, and testing either order of the inputs)
+    """
+    test_package = make_package("test-package", extras_require={"extra": []})
+    local_package_with_extra = from_line(f"{test_package}[extra]")
+    assert local_package_with_extra.req is None
+    local_package_without_extra = from_line(path_to_url(test_package))
+    assert local_package_without_extra.req is None
+
+    _test_combine_install_requirements_extras(
+        repository, local_package_with_extra, local_package_without_extra
+    )
+
+
 def test_compile_failure_shows_provenance(resolver, from_line):
     """
     Provenance of conflicting dependencies should be printed on failure.
